@@ -219,7 +219,7 @@ TW_UINT16 DataSource::Capability (TW_UINT16 MSG, pTW_CAPABILITY capability) {
                 case MSG_SET:
 
                     if (capability->ConType != TWON_ONEVALUE) return SetStatus (TWCC_BADVALUE);
-                    if (((pTW_ONEVALUE) *capability->hContainer)->Item != (TW_UINT32) -1)
+                    if (((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item != (TW_UINT32) -1)
                         return SetStatus (TWCC_BADVALUE);
                     return TWRC_SUCCESS;
                     break;
@@ -313,7 +313,7 @@ TW_UINT16 DataSource::Capability (TW_UINT16 MSG, pTW_CAPABILITY capability) {
                 case MSG_SET:
 
                     if (capability->ConType != TWON_ONEVALUE) return SetStatus (TWCC_BADVALUE);
-                    if (((pTW_ONEVALUE) *capability->hContainer)->Item != TWUN_INCHES)
+                    if (((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item != TWUN_INCHES)
                         return SetStatus (TWCC_BADVALUE);
                     return TWRC_SUCCESS;
                     break;
@@ -355,7 +355,7 @@ TW_UINT16 DataSource::Capability (TW_UINT16 MSG, pTW_CAPABILITY capability) {
                 case MSG_SET:
 
                     if (capability->ConType != TWON_ONEVALUE) return SetStatus (TWCC_BADVALUE);
-                    cap_XferMech = ((pTW_ONEVALUE) *capability->hContainer)->Item;
+                    cap_XferMech = ((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item;
                     if (cap_XferMech != TWSX_NATIVE && cap_XferMech != TWSX_MEMORY) {
                         cap_XferMech = TWSX_NATIVE;
                         return TWRC_CHECKSTATUS;
@@ -444,7 +444,7 @@ TW_UINT16 DataSource::Capability (TW_UINT16 MSG, pTW_CAPABILITY capability) {
                 case MSG_SET:
 
                     if (capability->ConType != TWON_ONEVALUE) return SetStatus (TWCC_BADVALUE);
-                    indicators = ((pTW_ONEVALUE) *capability->hContainer)->Item;
+                    indicators = ((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item;
                     return TWRC_SUCCESS;
                     break;
 
@@ -792,7 +792,7 @@ TW_UINT16 DataSource::Capability (TW_UINT16 MSG, pTW_CAPABILITY capability) {
                 case MSG_SET:
 
                     if (capability->ConType != TWON_ONEVALUE) return SetStatus (TWCC_BADVALUE);
-                    if (((pTW_ONEVALUE) *capability->hContainer)->Item != TWBO_MSBFIRST)
+                    if (((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item != TWBO_MSBFIRST)
                         return SetStatus (TWCC_BADVALUE);
                     return TWRC_SUCCESS;
                     break;
@@ -1291,18 +1291,18 @@ static const short ItemSize[] = {
 TW_UINT16 DataSource::BuildArray (pTW_CAPABILITY capability, TW_UINT16 type,
                                   TW_UINT32 numItems, void * values) {
 
-    capability->hContainer = NewHandle (sizeof (TW_ARRAY) - sizeof (TW_UINT8) +
+    capability->hContainer = (TW_HANDLE) NewHandle (sizeof (TW_ARRAY) - sizeof (TW_UINT8) +
                                         numItems * ItemSize [type]);
     if (!capability->hContainer) return SetStatus (TWCC_LOWMEMORY);
 
     capability->ConType = TWON_ARRAY;
 
-    HLock (capability->hContainer);
-    pTW_ARRAY pArray = (pTW_ARRAY) (*capability->hContainer);
+    HLock ((Handle) capability->hContainer);
+    pTW_ARRAY pArray = (pTW_ARRAY) *(Handle) capability->hContainer;
     pArray->ItemType = type;
     pArray->NumItems = numItems;
     memcpy (pArray->ItemList, values, numItems * ItemSize [type]);
-    HUnlock (capability->hContainer);
+    HUnlock ((Handle) capability->hContainer);
 
     return TWRC_SUCCESS;
 }
@@ -1312,20 +1312,20 @@ TW_UINT16 DataSource::BuildEnumeration (pTW_CAPABILITY capability, TW_UINT16 typ
                                         TW_UINT32 numItems, TW_UINT32 currentIndex,
                                         TW_UINT32 defaultIndex, void * values) {
 
-    capability->hContainer = NewHandle (sizeof (TW_ENUMERATION) - sizeof (TW_UINT8) +
+    capability->hContainer = (TW_HANDLE) NewHandle (sizeof (TW_ENUMERATION) - sizeof (TW_UINT8) +
                                         numItems * ItemSize [type]);
     if (!capability->hContainer) return SetStatus (TWCC_LOWMEMORY);
 
     capability->ConType = TWON_ENUMERATION;
 
-    HLock (capability->hContainer);
-    pTW_ENUMERATION pEnumeration = (pTW_ENUMERATION) (*capability->hContainer);
+    HLock ((Handle) capability->hContainer);
+    pTW_ENUMERATION pEnumeration = (pTW_ENUMERATION) *(Handle) capability->hContainer;
     pEnumeration->ItemType = type;
     pEnumeration->NumItems = numItems;
     pEnumeration->CurrentIndex = currentIndex;
     pEnumeration->DefaultIndex = defaultIndex;
     memcpy (pEnumeration->ItemList, values, numItems * ItemSize [type]);
-    HUnlock (capability->hContainer);
+    HUnlock ((Handle) capability->hContainer);
 
     return TWRC_SUCCESS;
 }
@@ -1333,16 +1333,16 @@ TW_UINT16 DataSource::BuildEnumeration (pTW_CAPABILITY capability, TW_UINT16 typ
 
 TW_UINT16 DataSource::BuildOneValue (pTW_CAPABILITY capability, TW_UINT16 type, TW_UINT32 value) {
 
-    capability->hContainer = NewHandle (sizeof (TW_ONEVALUE));
+    capability->hContainer = (TW_HANDLE) NewHandle (sizeof (TW_ONEVALUE));
     if (!capability->hContainer) return SetStatus (TWCC_LOWMEMORY);
 
     capability->ConType = TWON_ONEVALUE;
 
-    HLock (capability->hContainer);
-    pTW_ONEVALUE pOneValue = (pTW_ONEVALUE) (*capability->hContainer);
+    HLock ((Handle) capability->hContainer);
+    pTW_ONEVALUE pOneValue = (pTW_ONEVALUE) *(Handle) capability->hContainer;
     pOneValue->ItemType = type;
     pOneValue->Item = value;
-    HUnlock (capability->hContainer);
+    HUnlock ((Handle) capability->hContainer);
 
     return TWRC_SUCCESS;
 }
@@ -1350,16 +1350,16 @@ TW_UINT16 DataSource::BuildOneValue (pTW_CAPABILITY capability, TW_UINT16 type,
 
 TW_UINT16 DataSource::BuildOneValue (pTW_CAPABILITY capability, TW_UINT16 type, TW_FIX32 value) {
 
-    capability->hContainer = NewHandle (sizeof (TW_ONEVALUE));
+    capability->hContainer = (TW_HANDLE) NewHandle (sizeof (TW_ONEVALUE));
     if (!capability->hContainer) return SetStatus (TWCC_LOWMEMORY);
 
     capability->ConType = TWON_ONEVALUE;
 
-    HLock (capability->hContainer);
-    pTW_ONEVALUE pOneValue = (pTW_ONEVALUE) (*capability->hContainer);
+    HLock ((Handle) capability->hContainer);
+    pTW_ONEVALUE pOneValue = (pTW_ONEVALUE) *(Handle) capability->hContainer;
     pOneValue->ItemType = type;
     pOneValue->Item = *((TW_UINT32*) &value);
-    HUnlock (capability->hContainer);
+    HUnlock ((Handle) capability->hContainer);
 
     return TWRC_SUCCESS;
 }
@@ -1369,20 +1369,20 @@ TW_UINT16 DataSource::BuildRange (pTW_CAPABILITY capability, TW_UINT16 type,
                                   TW_UINT32 min, TW_UINT32 max, TW_UINT32 step,
                                   TW_UINT32 defvalue, TW_UINT32 value) {
 
-    capability->hContainer = NewHandle (sizeof(TW_RANGE));
+    capability->hContainer = (TW_HANDLE) NewHandle (sizeof(TW_RANGE));
     if (!capability->hContainer) return SetStatus (TWCC_LOWMEMORY);
 
     capability->ConType = TWON_RANGE;
 
-    HLock (capability->hContainer);
-    pTW_RANGE pRange = (pTW_RANGE) (*capability->hContainer);
+    HLock ((Handle) capability->hContainer);
+    pTW_RANGE pRange = (pTW_RANGE) *(Handle) capability->hContainer;
     pRange->ItemType = type;
     pRange->MinValue = min;
     pRange->MaxValue = max;
     pRange->StepSize = step;
     pRange->DefaultValue = defvalue;
     pRange->CurrentValue = value;
-    HUnlock (capability->hContainer);
+    HUnlock ((Handle) capability->hContainer);
 
     return TWRC_SUCCESS;
 }
@@ -1392,20 +1392,20 @@ TW_UINT16 DataSource::BuildRange (pTW_CAPABILITY capability, TW_UINT16 type,
                                   TW_FIX32 min, TW_FIX32 max, TW_FIX32 step,
                                   TW_FIX32 defvalue, TW_FIX32 value) {
 
-    capability->hContainer = NewHandle (sizeof(TW_RANGE));
+    capability->hContainer = (TW_HANDLE) NewHandle (sizeof(TW_RANGE));
     if (!capability->hContainer) return SetStatus (TWCC_LOWMEMORY);
 
     capability->ConType = TWON_RANGE;
 
-    HLock (capability->hContainer);
-    pTW_RANGE pRange = (pTW_RANGE) (*capability->hContainer);
+    HLock ((Handle) capability->hContainer);
+    pTW_RANGE pRange = (pTW_RANGE) *(Handle) capability->hContainer;
     pRange->ItemType = type;
     pRange->MinValue = *((TW_UINT32*) &min);
     pRange->MaxValue = *((TW_UINT32*) &max);
     pRange->StepSize = *((TW_UINT32*) &step);
     pRange->DefaultValue = *((TW_UINT32*) &defvalue);
     pRange->CurrentValue = *((TW_UINT32*) &value);
-    HUnlock (capability->hContainer);
+    HUnlock ((Handle) capability->hContainer);
 
     return TWRC_SUCCESS;
 }
