@@ -14,17 +14,17 @@ cat Info.plist.in |
 	<key>CFBundleIconFile</key>
 	<string>SANE.icns</string>
 	<key>CFBundleIdentifier</key>
-	<string>se.ellert.twain-sane</string>
+	<string>\$(PRODUCT_BUNDLE_IDENTIFIER)</string>
 	<key>CFBundleInfoDictionaryVersion</key>
 	<string>6.0</string>
 	<key>CFBundlePackageType</key>
 	<string>APPL</string>
 	<key>CFBundleShortVersionString</key>
-	<string>3.4</string>
+	<string>3.5</string>
 	<key>CFBundleSignature</key>
 	<string>SANE</string>
 	<key>CFBundleVersion</key>
-	<string>3.4</string>
+	<string>3.5</string>
 	<key>CSResourcesFileMapped</key>
 	<true/>
 	<key>SANELocaleDir</key>
