@@ -554,10 +554,10 @@ TW_UINT16 SaneDevice::GetCustomData (pTW_CUSTOMDSDATA customdata) {
     CFRelease (dataDictionary);
 
     customdata->InfoLength = CFDataGetLength (xml);
-    customdata->hData = NewHandle (customdata->InfoLength);
-    HLock (customdata->hData);
-    CFDataGetBytes (xml, CFRangeMake (0, customdata->InfoLength), (UInt8 *) *customdata->hData);
-    HUnlock (customdata->hData);
+    customdata->hData = (TW_HANDLE) NewHandle (customdata->InfoLength);
+    HLock ((Handle) customdata->hData);
+    CFDataGetBytes (xml, CFRangeMake (0, customdata->InfoLength), (UInt8 *) *(Handle) customdata->hData);
+    HUnlock ((Handle) customdata->hData);
 
     CFRelease (xml);
 
@@ -569,9 +569,9 @@ TW_UINT16 SaneDevice::SetCustomData (pTW_CUSTOMDSDATA customdata) {
 
     bool done = false;
 
-    HLock (customdata->hData);
-    CFDataRef xml = CFDataCreate (NULL, (UInt8 *) *customdata->hData, customdata->InfoLength);
-    HUnlock (customdata->hData);
+    HLock ((Handle) customdata->hData);
+    CFDataRef xml = CFDataCreate (NULL, (UInt8 *) *(Handle) customdata->hData, customdata->InfoLength);
+    HUnlock ((Handle) customdata->hData);
 
     CFDictionaryRef dataDictionary =
         (CFDictionaryRef) CFPropertyListCreateFromXMLData (NULL, xml, kCFPropertyListImmutable, NULL);
@@ -1341,7 +1341,7 @@ TW_UINT16 SaneDevice::SetPixelType (pTW_CAPABILITY capability) {
 
     if (capability) {
         if (capability->ConType != TWON_ONEVALUE) return datasource->SetStatus (TWCC_BADVALUE);
-        pixeltype = ((pTW_ONEVALUE) *capability->hContainer)->Item;
+        pixeltype = ((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item;
         // fallback to gray if binary/lineart/halftone does not exist
         if (pixeltype == TWPT_BW && !havebw) {
             pixeltype = TWPT_GRAY;
@@ -1479,7 +1479,7 @@ TW_UINT16 SaneDevice::SetBitDepth (pTW_CAPABILITY capability) {
 
     if (capability) {
         if (capability->ConType != TWON_ONEVALUE) return datasource->SetStatus (TWCC_BADVALUE);
-        bitdepth = ((pTW_ONEVALUE) *capability->hContainer)->Item;
+        bitdepth = ((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item;
     }
     else {
         switch (optdesc->constraint_type) {
@@ -1729,9 +1729,9 @@ TW_UINT16 SaneDevice::SetXResolution (pTW_CAPABILITY capability) {
     if (capability) {
         if (capability->ConType != TWON_ONEVALUE) return datasource->SetStatus (TWCC_BADVALUE);
         if (optdesc->type == SANE_TYPE_INT)
-            xres = SANE_FIX2INT (T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *capability->hContainer)->Item))));
+            xres = SANE_FIX2INT (T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item))));
         else
-            xres = T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *capability->hContainer)->Item)));
+            xres = T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item)));
     }
     else {
         if (optdesc->type == SANE_TYPE_INT)
@@ -1858,9 +1858,9 @@ TW_UINT16 SaneDevice::SetYResolution (pTW_CAPABILITY capability) {
     if (capability) {
         if (capability->ConType != TWON_ONEVALUE) return datasource->SetStatus (TWCC_BADVALUE);
         if (optdesc->type == SANE_TYPE_INT)
-            yres = SANE_FIX2INT (T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *capability->hContainer)->Item))));
+            yres = SANE_FIX2INT (T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item))));
         else
-            yres = T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *capability->hContainer)->Item)));
+            yres = T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item)));
     }
     else {
         if (optdesc->type == SANE_TYPE_INT)
@@ -2094,9 +2094,9 @@ TW_UINT16 SaneDevice::SetBrightness (pTW_CAPABILITY capability) {
     if (capability) {
         if (capability->ConType != TWON_ONEVALUE) return datasource->SetStatus (TWCC_BADVALUE);
         if (optdesc->type == SANE_TYPE_INT)
-            brightness = SANE_FIX2INT (T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *capability->hContainer)->Item))));
+            brightness = SANE_FIX2INT (T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item))));
         else
-            brightness = T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *capability->hContainer)->Item)));
+            brightness = T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item)));
     }
     else
         brightness = 0;
@@ -2218,9 +2218,9 @@ TW_UINT16 SaneDevice::SetContrast (pTW_CAPABILITY capability) {
     if (capability) {
         if (capability->ConType != TWON_ONEVALUE) return datasource->SetStatus (TWCC_BADVALUE);
         if (optdesc->type == SANE_TYPE_INT)
-            contrast = SANE_FIX2INT (T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *capability->hContainer)->Item))));
+            contrast = SANE_FIX2INT (T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item))));
         else
-            contrast = T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *capability->hContainer)->Item)));
+            contrast = T2S (*((TW_FIX32*) &(((pTW_ONEVALUE) *(Handle) capability->hContainer)->Item)));
     }
     else
         contrast = 0;
